@@ -1,7 +1,7 @@
 package Nodejs::Util;
 
-our $DATE = '2018-01-06'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $DATE = '2018-01-07'; # DATE
+our $VERSION = '0.009'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -76,10 +76,9 @@ $SPEC{nodejs_available} = {
     summary => 'Check the availability of Node.js',
     description => <<'_',
 
-This is a more advanced alternative to `get_nodejs_path()`. Will check for
-`node` or `nodejs` in the PATH, like `get_nodejs_path()`. But you can also
-specify minimum version (and other options in the future). And it will return
-more details.
+This is a more advanced alternative to `nodejs_path()`. Will check for `node` or
+`nodejs` in the PATH, like `nodejs_path()`. But you can also specify minimum
+version (and other options in the future). And it will return more details.
 
 Will return status 200 if everything is okay. Actual result will return the path
 to executable, and result metadata will contain extra result like detected
@@ -108,7 +107,7 @@ sub nodejs_available {
 
     my $paths = do {
         local $ENV{PATH} = $args{path} if defined $args{path};
-        get_nodejs_path(all => 1);
+        nodejs_path(all => 1);
     };
     defined $paths or return [412, "node.js not detected in PATH"];
 
@@ -284,7 +283,7 @@ Nodejs::Util - Utilities related to Node.js
 
 =head1 VERSION
 
-This document describes version 0.008 of Nodejs::Util (from Perl distribution Nodejs-Util), released on 2018-01-06.
+This document describes version 0.009 of Nodejs::Util (from Perl distribution Nodejs-Util), released on 2018-01-07.
 
 =for Pod::Coverage ^(get_nodejs_path)$
 
@@ -299,10 +298,9 @@ Usage:
 
 Check the availability of Node.js.
 
-This is a more advanced alternative to C<get_nodejs_path()>. Will check for
-C<node> or C<nodejs> in the PATH, like C<get_nodejs_path()>. But you can also
-specify minimum version (and other options in the future). And it will return
-more details.
+This is a more advanced alternative to C<nodejs_path()>. Will check for C<node> or
+C<nodejs> in the PATH, like C<nodejs_path()>. But you can also specify minimum
+version (and other options in the future). And it will return more details.
 
 Will return status 200 if everything is okay. Actual result will return the path
 to executable, and result metadata will contain extra result like detected
